#
# spec file for package john
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           john
Version:        1.8.0
Release:        11.11
Summary:        Detects Weak Passwords
License:        GPL-2.0+
Group:          Productivity/Security
Url:            http://www.openwall.com/john/
Source:         http://www.openwall.com/john/j/%{name}-%{version}.tar.xz
Source1:        http://www.openwall.com/john/j/%{name}-%{version}.tar.xz.sign
Source2:        %{name}.8.gz
Source3:        %{name}-rpmlintrc
Source4:        %{name}.keyring
Source6:        mailer.8
Source7:        relbench.8
%define         jumboversion john-1.7.9-jumbo-7
Source8:        %{jumboversion}.tar.bz2
Source9:        %{jumboversion}.tar.bz2.sign
Patch0:         ppc64le.patch
BuildRequires:  openssl-devel
%if 0%{?suse_version} == 1110 
BuildRequires:  xz
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define         johndir /var/lib/john
%define cflags CFLAGS="-c %{optflags} -DJOHN_SYSTEMWIDE=1 -finline-limit=2000 --param inline-unit-growth=2000" LDFLAGS="-lcrypto"
%ifarch x86_64
%define cflags CFLAGS="-c %{optflags} -DJOHN_SYSTEMWIDE=1" LDFLAGS="-lcrypto"
%endif

%description
John the Ripper is a fast password cracker (password security auditing
tool). Its primary purpose is to detect weak Unix passwords, but a
number of other hash types are supported as well.

%prep
%setup -q -a8
%patch0 -p1
cd %{jumboversion} && cp -a ./* ..
cd ..
rm -r %{jumboversion}
# adapt the configs
perl -pi -e "s#Wordlist = (.*)#Wordlist = %{johndir}/password.lst#g" $RPM_BUILD_DIR/%{name}-%{version}/run/john.conf
perl -pi -e 's#^(\#define JOHN_SYSTEMWIDE_EXEC)\s.+$#$1\t\"%{johndir}\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define CFG_FULL_NAME)\s.+$#$1\t\"%{_sysconfdir}/john.conf\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define CFG_ALT_NAME)\s.+$#$1\t\"%{_sysconfdir}/john.conf\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define WORDLIST_NAME)\s.+$#$1\t\"%{johndir}/password.lst\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define LOG_NAME)\s.+$#$1\t\"/var/log/john.log\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h
perl -pi -e 's#^(\#define JOHN_SYSTEMWIDE_HOME)\s.+$#$1\t\"%{johndir}\"#g' $RPM_BUILD_DIR/%{name}-%{version}/src/params.h

%build
%ifarch alpha
		TARGET=linux-alpha
%endif
%ifarch ia64
		TARGET=linux-ia64
%endif
%ifarch %ix86
%ifnarch i386 i486
		TARGET=linux-x86-mmx
%endif
%endif
%ifarch ppc
		TARGET=linux-ppc32
%endif
%ifarch ppc64 ppc64le
		TARGET=linux-ppc64
%endif
%ifarch sparc sparcv9
		TARGET=linux-sparc
%endif
%ifarch sparc64
		TARGET=solaris-sparc64-gcc
%endif
%ifarch x86_64
		TARGET=linux-x86-64
%endif
%ifarch %arm aarch64 m68k
		TARGET=generic
%endif
%ifarch %ix86
if test -z "$TARGET"; then
    TARGET=linux-x86-any
fi
%endif
export TARGET
pushd src
make clean $TARGET %{cflags} LDFLAGS='-lcrypto -lm -lz -lssl'
popd

%check
pushd src
make check
popd

%install
mkdir -p %{buildroot}{%{_bindir},%johndir,%{_sysconfdir},%{_mandir}/man8}
install -m 755 run/john %{buildroot}%{_bindir}/
cp -r run/un* %{buildroot}%{_bindir}/
install -m755 run/relbench %{buildroot}%{_bindir}/
install -m 644 -p run/{password.lst,*.chr,d*.conf,*local.conf} %{buildroot}%johndir/
install -m 644 -p run/john.conf %{buildroot}%{_sysconfdir}/
install -m 755 -p run/mailer %{buildroot}%{_bindir}/
# handle documentation - makes rpmlint happy
mkdir -p %{buildroot}%{_defaultdocdir}/%{name}
cp README-jumbo doc/* %{buildroot}%{_defaultdocdir}/%{name}/
rm %{buildroot}%{_defaultdocdir}/%{name}/INSTALL
# install man pages
install -m 644 -p %{SOURCE2} %{buildroot}%{_mandir}/man8/
install -Dm644 %{SOURCE6} %{buildroot}%{_mandir}/man8/mailer.8
install -Dm644 %{SOURCE7} %{buildroot}%{_mandir}/man8/relbench.8

%clean
rm -rf %{buildroot}

%files
%defattr(-,root,root)
%doc %{_defaultdocdir}/%{name}/
%doc %{_mandir}/man8/john.8*
%doc %{_mandir}/man8/mailer.8*
%doc %{_mandir}/man8/relbench.8*
%{_bindir}/un*
%{_bindir}/relbench
%dir %{johndir}
%attr(750,root,wheel) %{_bindir}/john
%{_bindir}/mailer
%attr(644,root,root) %johndir/password.lst
%attr(644,root,root) %johndir/*.chr
%attr(644,root,root) %johndir/d*.conf
%attr(644,root,root) %johndir/*local.conf
%config (noreplace) %{_sysconfdir}/john.conf

%changelog
* Thu Jun 25 2015 astieger@suse.com
- fix SLE 11 SP3 build
* Mon Dec 15 2014 lars@linux-schulserver.de
- include "jumbo patch" into the build - special thanks to
  Mark Draheim for the specfile patch (closes bnc #839246)
* Fri Jan 10 2014 dvaleev@suse.com
- Fix build on ppc64le
- added patches:
  * ppc64le.patch
* Mon Oct 28 2013 schwab@suse.de
- Use the generic target for m68k
* Wed Oct  9 2013 lars@linux-schulserver.de
- update to 1.8.0:
  + Revised the incremental mode to let the current character counts
    grow for each character position independently, with the aim to
    improve efficiency in terms of successful guesses per candidate
    passwords tested.
  + Revised the pre-defined incremental modes, as well as external
    mode filters that are used to generate .chr files.
  + Added makechr, a script to (re-)generate .chr files.
  + Enhanced the status reporting to include four distinct speed
    metrics (g/s, p/s, c/s, and C/s).
  + Added the "--fork=N" and "--node=MIN[-MAX]/TOTAL" options for
    trivial parallel and distributed processing.
  + In the external mode compiler, treat character literals as unsigned.
  + Renamed many of the formats.
  + Updated the documentation.
  + Relaxed the license for many source files to cut-down BSD.
  + Relaxed the license for John the Ripper as a whole from GPLv2
    (exact version) to GPLv2 or newer with optional OpenSSL and
    unRAR exceptions.
  + Assorted other changes have been made.
- add simple man pages for relbench and mailer scripts
- disable jumbo patch for now until a version for 1.8.0 is out
* Sun Mar 17 2013 schwab@suse.de
- Use the generic target for aarch64
* Sat Oct 20 2012 lars@linux-schulserver.de
- updated jumbo patch to 1.7.9-jumbo-7
* Fri Jul 13 2012 lars@linux-schulserver.de
- update to 1.7.9:
  + Added optional parallelization of the MD5-based crypt(3) code with OpenMP.
  + Added optional parallelization of the bitslice DES code with OpenMP.
  + Replaced the bitslice DES key setup algorithm with a faster one, which
    significantly improves performance at LM hashes, as well as at DES-based
    crypt(3) hashes when there's just one salt (or very few salts).
  + Optimized the DES S-box x86-64 (16-register SSE2) assembly code.
  + Added support for 10-character DES-based tripcodes (not optimized yet).
  + Added support for the "$2y$" prefix of bcrypt hashes.
  + Added two more hash table sizes (16M and 128M entries) for faster processing
    of very large numbers of hashes per salt (over 1M).
  + Added two pre-defined external mode variables: "abort" and "status", which
    let an external mode request the current cracking session to be aborted or the
    status line to be displayed, respectively.
  + Made some minor optimizations to external mode function calls and virtual
    machine implementation.
  + The "--make-charset" option now uses floating-point rather than 64-bit
    integer operations, which allows for larger CHARSET_* settings in params.h.
  + Added runtime detection of Intel AVX and AMD XOP instruction set extensions,
    with optional fallback to an alternate program binary.
  + Added relbench, a Perl script to compare two "john --test" benchmark runs,
    such as for different machines, "make" targets, C compilers, optimization
    options, or/and versions of John the Ripper.
  + Additional public lists of "top N passwords" have been merged into the
    bundled common passwords list, and some insufficiently common passwords were
    removed from the list.
  + Many minor enhancements and a few bug fixes were made.
- updated jumbo patch to 1.7.9-jumbo-6
- specfile cleanup (using spec-cleaner)
* Fri Sep 30 2011 joop.boonen@boonen.org
- Added a fix for the arm architecture, TARGET generic
* Fri Jul  8 2011 lars@linux-schulserver.de
- update to 1.7.8:
  + many changes, please see /usr/share/doc/packages/john/CHANGES
  + The bitslice DES S-box expressions have been replaced with those
    generated by Roman Rusakov specifically for John the Ripper
  + Added Intel AVX and AMD XOP instruction sets support for bitslice DES
  + Apache "$apr1$" MD5-based password hashes are now supported.
  + the loader now includes logic to warn the user of ambiguous
    hash encodings
  + "DateTime", "Repeats", "Subsets", "AtLeast1-Simple",
    "AtLeast1-Generic", and "Policy" external mode samples have been
    added to the default john.conf
  + A few minor bug fixes and enhancements were made
  + Corrected a logic error introduced in JtR 1.7.4.2: in
    "single crack" mode
- added and updated jumbo patch
* Tue Mar 15 2011 draht@suse.de
- go from jumbo patch 7 to 12
- needs -lm to link, via LDFLAGS from make command in spec
* Thu Sep  9 2010 lars@linux-schulserver.de
- update to 1.7.6:
  + Generic crypt(3) support (enabled with "--format=crypt") has been
    added for auditing password hash types supported by the system but
    not yet supported by John's own optimized cryptographic routines
    (such as "SHA-crypt" and SunMD5).
  + Optional parallelization of the above has been implemented by
    means of OpenMP along with glibc's crypt_r(3)
  + Optional parallelization of John's own optimized code for the
    OpenBSD-style Blowfish-based crypt(3) (bcrypt) hashes with OpenMP
    has been added
  + A more suitable version of 32-bit x86 assembly code for Blowfish
    is now chosen on Core i7 and similar CPUs (in 32 bit mode)
  + More optimal DES S-box expressions for PowerPC with AltiVec
  + The bitslice DES C source code has been reworked to allow for
    the use of arbitrary SIMD intrinsics, which was previously only
    implemented for AltiVec as a special case
  + Support for SSE2 and MMX intrinsics with bitslice DES (as an
    alternative to the supplied assembly code) has been added
    (currently only enabled for SSE2 on x86-64)
  + Support for mixed-type longer virtual vectors (such as SSE2+MMX,
    SSE2+ALU, AltiVec+ALU, and other combinations) with bitslice
    DES has been added
  + The loader will now detect password hashes specified on a line
    on their own, not only as part of an /etc/passwd or PWDUMP
    format file
  + When run in "--stdin" mode and reading candidate passwords from
    a terminal (to be typed by the user), John will no longer mess
    with the terminal settings
  + John will now restore terminal settings not only on normal
    termination or interrupt, but also when forcibly interrupted
    with two Ctrl-C keypresses
  + A new numeric variable has been added to the word mangling rules
    engine: "p" for position of the character last found with the
    "/" or "%%" commands
  + Support for the use of "--format" along with "--show" or
    "--make-charset" has been added
  + The choice of .rec and .log filenames for custom session names
    has been made more intuitive
  + Support for "\r" (character lists with repeats) and "\p0"
    (reference to the immediately preceding character list/range)
    has been added to the word mangling rules preprocessor
  + The undefined and undocumented behavior of some subtle word
    mangling rules preprocessor constructs has been changed to
    arguably be more sensible
* Thu Feb 11 2010 lrupp@suse.de
- update to 1.7.4.2:
  + Major performance improvements
  + John will now tend to use more memory to achieve better speed
  + Some previously missed common website passwords found on public
    lists of "top N passwords" have been added to the bundled common
    passwords list.
  + Support for back-references and "parallel" ranges has been
    added to the word mangling rules preprocessor.
  + The notion of numeric variables has been introduced into the
    rules engine.
  + New rule commands have been added
  + New rule reject flags have been added
  + The default rulesets for "single crack" and wordlist modes have
    been revised to make use of the new features, for speed, to
    produce fewer duplicates, and to attempt additional kinds of
    candidate passwords.
  + The default for the Idle setting has been changed from N to Y.
* Mon Feb  8 2010 jengelh@medozas.de
- only build MMX variant on >= i586
- guard TARGET=linux-x86-any with %%ix86
- enable building on sparcv9
* Mon Sep 28 2009 lrupp@suse.de
- update to 1.7.3.4:
  + "make check" has been implemented
  + The "--test" option will now take an optional argument - the
    duration of each benchmark in seconds
  + Some very minor bugs that did not affect normal operation have
    been fixed.
  + Some unimportant compiler warnings have been fixed, a source code
    comment has been made more verbose and more complete.
* Tue Sep  9 2008 lrupp@suse.de
- update to 1.7.3.1:
  + Two Blowfish-based crypt(3) hashes may now be computed in
    parallel for much better performance on modern multi-issue CPUs
    with a sufficient number of registers (e.g., x86_64).
  + New make targets: macosx-universal, macosx-x86-64, solaris-x86-64-cc,
    solaris-x86-64-gcc, solaris-x86-sse2-cc, solaris-x86-sse2-gcc,
    solaris-x86-mmx-cc, solaris-x86-mmx-gcc, solaris-x86-any-cc,
    linux-ia64;
  + Minor bug fixes.
  + "DumbForce" and "KnownForce" external mode samples have been
    added to the default john.conf.
- removed the outdated patchset (needs to be re-integrated)
* Mon Sep 25 2006 lrupp@suse.de
- remove double cflags definition
* Thu Jun  8 2006 lrupp@suse.de
- new version 1.7.2
- moved john.conf to /etc
- moved john binary to /usr/bin
- enabled some opt flags (must be tested)
* Wed May 17 2006 schwab@suse.de
- Use RPM_OPT_FLAGS.
- Don't strip binaries.
- Fix last change.
* Mon Mar 27 2006 lrupp@suse.de
- use CFLAGS instead of params.h.patch
* Fri Mar 24 2006 lrupp@suse.de
- charset.tar.bz2 is included upstream
- reduce build requires
- new version 1.7.0.2
* Mon Mar 13 2006 lrupp@suse.de
- new version 1.7.0.1
- adapt patches to new version
- disabled some compiler fixes
- removed RPM_OPT_FLAGS => performance issue atm
* Mon Mar 13 2006 lrupp@suse.de
- split off worlists to an extra package
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 schwab@suse.de
- Don't strip binaries.
- Fix ia64 configuration.
* Mon Dec 19 2005 aosthof@suse.de
- Fixed .spec file for all architectures besides x86
- Added targets for ia64 / s390 / s390x
* Fri Nov 11 2005 kukuk@suse.de
- Fix compiling with glibc 2.4 snapshot
* Wed Sep 14 2005 lrupp@suse.de
- new version 1.6.39
- use noreplace for config
* Wed Jun 15 2005 meissner@suse.de
- use RPM_OPT_FLAGS.
* Sun Jun  5 2005 ro@suse.de
- added directory to filelist
* Fri Jun  3 2005 lrupp@suse.de
- changed manpage
- added patches from ftp.openwall.com again:
  + blowfish (Eggdrop blowfish)
  + md5 (work with md5 hash of apache; faster)
  + rawMD5
  + MySQL (about 75%% faster than mysqlpassword.c)
- enabled global mode in params.g again
* Mon May 30 2005 lrupp@suse.de
- added "all" wordlist from openwall
- enabled arch-support for sparc and ppc
- added old doc-files from 1.6
* Wed May 25 2005 lrupp@suse.de
- new package, version 1.6.38
* Tue Jan 25 2005 lrupp@suse.de
- added some wordlists to get more options ;-)
- added patches from ftp.openwall.com to provide support for
  additiional password formats:
  + blowfish
  + md5
  + rawMD5
* Mon Aug  2 2004 lrupp@suse.de
- - fixed BugTraq-ID: 43287
- enabled global-mode in params.h
- fix misspelling in manpage
* Fri Feb 27 2004 lrupp@suse.de
- use devel version: no segfault on x86-64
- included documentation and charsets from old version
- renamed new john.conf in john.ini
- created a short manpage for john
- created symlink /var/lib/john/john
* Mon Nov 10 2003 ro@suse.de
- use defattr
* Fri Nov  7 2003 lrupp@suse.de
- added '# norootforbuild' in the spec-file
* Thu Jun 12 2003 poeml@suse.de
- add /var/lib/john to the filelist
* Fri May 23 2003 coolo@suse.de
- use BuildRoot
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Fri Jul  5 2002 kukuk@suse.de
- use %%ix86
* Thu Mar 29 2001 uli@suse.de
- fixed for gcc >2.95
- replaced config.guess stuff with %%ifarch
* Wed Mar  1 2000 werner@suse.de
- Fix config.guess selection
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Mar 18 1999 uli@suse.de
- new package, version 1.6
